@@ -1,21 +1,10 @@
 /* This file is part of FSView.
-   Copyright (C) 2002, 2003 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
-   Some file management code taken from the Dolphin file manager (C) 2006-2009,
-   by Peter Penz <peter.penz19@mail.com>
+    SPDX-FileCopyrightText: 2002, 2003 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
 
-   KCachegrind is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation, version 2.
+    Some file management code taken from the Dolphin file manager:
+    SPDX-FileCopyrightText: 2006-2009 Peter Penz <peter.penz19@mail.com>
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-only
 */
 
 /*
@@ -332,11 +321,11 @@ void FSViewPart::setNonStandardActionEnabled(const char *actionName, bool enable
 void FSViewPart::updateActions()
 {
     int canDel = 0, canCopy = 0, canMove = 0;
-    QList<QUrl> urls;
 
-    foreach (TreeMapItem *i, _view->selection()) {
-        QUrl u = QUrl::fromLocalFile(((Inode *)i)->path());
-        urls.append(u);
+    const auto selectedItems = _view->selection();
+    for (TreeMapItem *item : selectedItems) {
+        Inode *inode = static_cast<Inode *>(item);
+        const QUrl u = QUrl::fromLocalFile(inode->path());
         canCopy++;
         if (KProtocolManager::supportsDeleting(u)) {
             canDel++;
@@ -356,7 +345,8 @@ void FSViewPart::updateActions()
     setNonStandardActionEnabled("editMimeType", _view->selection().count() == 1);
     setNonStandardActionEnabled("properties", _view->selection().count() == 1);
 
-    emit _ext->selectionInfo(urls);
+    const KFileItemList items = selectedFileItems();
+    emit _ext->selectionInfo(items);
 
     if (canCopy > 0) {
         stateChanged(QStringLiteral("has_selection"));
@@ -367,20 +357,33 @@ void FSViewPart::updateActions()
     qCDebug(FSVIEWLOG) << "deletable" << canDel;
 }
 
-void FSViewPart::contextMenu(TreeMapItem * /*item*/, const QPoint &p)
+KFileItemList FSViewPart::selectedFileItems() const
 {
-    int canDel = 0, canCopy = 0, canMove = 0;
+    const auto selectedItems = _view->selection();
     KFileItemList items;
-
-    foreach (TreeMapItem *i, _view->selection()) {
-        QUrl u = QUrl::fromLocalFile(((Inode *)i)->path());
-        QString mimetype = ((Inode *)i)->mimeType().name();
-        const QFileInfo &info = ((Inode *)i)->fileInfo();
+    items.reserve(selectedItems.count());
+    for (TreeMapItem *item : selectedItems) {
+        Inode *inode = static_cast<Inode *>(item);
+        const QUrl u = QUrl::fromLocalFile(inode->path());
+        const QString mimetype = inode->mimeType().name();
+        const QFileInfo &info = inode->fileInfo();
         mode_t mode =
             info.isFile() ? S_IFREG :
             info.isDir() ? S_IFDIR :
             info.isSymLink() ? S_IFLNK : (mode_t) - 1;
         items.append(KFileItem(u, mimetype, mode));
+     }
+     return items;
+}
+
+void FSViewPart::contextMenu(TreeMapItem * /*item*/, const QPoint &p)
+{
+    int canDel = 0, canCopy = 0, canMove = 0;
+
+    const auto selectedItems = _view->selection();
+    for (TreeMapItem *item : selectedItems) {
+        Inode *inode = static_cast<Inode *>(item);
+        const QUrl u = QUrl::fromLocalFile(inode->path());
 
         canCopy++;
         if (KProtocolManager::supportsDeleting(u)) {
@@ -425,6 +428,7 @@ void FSViewPart::contextMenu(TreeMapItem * /*item*/, const QPoint &p)
 //       editActions.append(actionCollection()->action("rename"));
     actionGroups.insert(QStringLiteral("editactions"), editActions);
 
+    const KFileItemList items = selectedFileItems();
     if (items.count() > 0)
         emit _ext->popupMenu(_view->mapToGlobal(p), items,
                              KParts::OpenUrlArguments(),
