@@ -1,21 +1,9 @@
 /* This file is part of the KDE project
 
-Copyright (C) 2001, 2003 Lukas Tinkl <lukas@kde.org>
-Andreas Schlapbach <schlpbch@iam.unibe.ch>
+    SPDX-FileCopyrightText: 2001, 2003 Lukas Tinkl <lukas@kde.org>
+    SPDX-FileCopyrightText: Andreas Schlapbach <schlpbch@iam.unibe.ch>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public
-License version 2 as published by the Free Software Foundation.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public License
-along with this library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "imgallerydialog.h"
@@ -35,6 +23,7 @@ Boston, MA 02110-1301, USA.
 #include <kconfiggroup.h>
 #include <kguiitem.h>
 #include <kfontchooser.h>
+#include <kwidgetsaddons_version.h>
 
 KIGPDialog::KIGPDialog(QWidget *parent, const QString &path)
     : KPageDialog(parent)
@@ -117,8 +106,14 @@ void KIGPDialog::setupLookPage(const QString &path)
 
     m_fontName = new QComboBox(page);
     m_fontName->setSizePolicy(QSizePolicy::MinimumExpanding, m_fontName->sizePolicy().verticalPolicy());
+
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 86, 0)
+    const QStringList standardFonts = KFontChooser::createFontList(KFontChooser::NoDisplayFlags);
+#else
     QStringList standardFonts;
     KFontChooser::getFontList(standardFonts, 0);
+#endif
+
     m_fontName->addItems(standardFonts);
     m_fontName->setItemText(m_fontName->currentIndex(), look.readEntry("FontName", QFontDatabase::systemFont(QFontDatabase::GeneralFont).family()));
     form->addRow(i18n("Fon&t name:"), m_fontName);
