@@ -1,19 +1,8 @@
-/***************************************************************************
-                               sidebar_part.h
-                             -------------------
-    begin                : Sat June 2 16:25:27 CEST 2001
-    copyright            : (C) 2001 Joseph Wenninger
-    email                : jowenn@kde.org
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2001 Joseph Wenninger <jowenn@kde.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
 #ifndef KONQSIDEBARPART_H
 #define KONQSIDEBARPART_H
 
