@@ -1,24 +1,11 @@
 /*
-   This file is part of the KDE project
-   Copyright (C) 1998, 1999 Simon Hausmann <hausmann@kde.org>
-   Copyright (C) 2000-2004 David Faure <faure@kde.org>
-   Copyright (C) 2007 Eduardo Robles Elvira <edulix@gmail.com>
-   Copyright (C) 2007 Daniel García Moreno <danigm@gmail.com>
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1998, 1999 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 2000-2004 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2007 Eduardo Robles Elvira <edulix@gmail.com>
+    SPDX-FileCopyrightText: 2007 Daniel García Moreno <danigm@gmail.com>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef KONQMAINWINDOW_H
@@ -558,6 +545,8 @@ private Q_SLOTS:
      * to Konqueror's own and emits the spellCheckConfigurationChanged signal
      */
     void updateSpellCheckConfiguration();
+
+    void inspectCurrentPage();
     
 private:
     void updateWindowIcon();
@@ -673,6 +662,8 @@ private: // members
 
     KToggleFullScreenAction *m_ptaFullScreen;
 
+    QAction *m_paShowDeveloperTools;
+
     bool m_fullyConstructed: 1;
     bool m_bLocationBarConnected: 1;
     bool m_bURLEnterLock: 1;
