@@ -1,22 +1,9 @@
 /*  This file is part of the KDE project
 
-    Copyright (C) 2002-2003 Konqueror Developers <konq-e@kde.org>
-    Copyright (C) 2002-2003 Douglas Hanley <douglash@caltech.edu>
+    SPDX-FileCopyrightText: 2002-2003 Konqueror Developers <konq-e@kde.org>
+    SPDX-FileCopyrightText: 2002-2003 Douglas Hanley <douglash@caltech.edu>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-    MA  02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "konqtabs.h"
