@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 1999 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 1999 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "webenginesettings.h"
@@ -34,6 +21,7 @@
 #include <QWebEngineSettings>
 #include <QFontDatabase>
 #include <QFileInfo>
+#include <QDir>
 
 QDataStream & operator<<(QDataStream& ds, const WebEngineSettings::WebFormInfo& info)
 {
@@ -348,7 +336,6 @@ void WebEngineSettings::init( KConfig * config, bool reset )
   }
 
   KConfigGroup cgFilter( config, "Filter Settings" );
-
   if ((reset || cgFilter.exists()) && (d->m_adFilterEnabled = cgFilter.readEntry("Enabled", false)))
   {
       d->m_hideAdsEnabled = cgFilter.readEntry("Shrink", false);
@@ -387,7 +374,9 @@ void WebEngineSettings::init( KConfig * config, bool reset )
               if (filterEnabled && url.isValid()) {
                   /** determine where to cache HTMLFilterList file */
                   QString localFile = cgFilter.readEntry(QStringLiteral("HTMLFilterListLocalFilename-").append(QString::number(id)));
-                  localFile = QStandardPaths::locate(QStandardPaths::ConfigLocation, "khtml/", QStandardPaths::LocateDirectory) + localFile;
+                  QString dirName = QStandardPaths::writableLocation(QStandardPaths::CacheLocation);
+                  QDir().mkpath(dirName);
+                  localFile =  dirName + '/' + localFile;
 
                   /** determine existence and age of cache file */
                   QFileInfo fileInfo(localFile);
