@@ -1,24 +1,12 @@
 /*
- * This file is part of the KDE project.
- *
- * Copyright (C) 2008 Dirk Mueller <mueller@kde.org>
- * Copyright (C) 2008 - 2010 Urs Wolfer <uwolfer @ kde.org>
- * Copyright (C) 2009 Dawit Alemayehu <adawit@kde.org>
- *
- * This library is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as published by the
- * Free Software Foundation; either version 2.1 of the License, or (at your
- * option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
- * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    This file is part of the KDE project.
+
+    SPDX-FileCopyrightText: 2008 Dirk Mueller <mueller@kde.org>
+    SPDX-FileCopyrightText: 2008-2010 Urs Wolfer <uwolfer @ kde.org>
+    SPDX-FileCopyrightText: 2009 Dawit Alemayehu <adawit@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "webenginepage.h"
 
@@ -28,6 +16,7 @@
 #include "webenginepartdownloadmanager.h"
 #include "webenginewallet.h"
 #include <webenginepart_debug.h>
+#include "webenginepartcertificateerrordlg.h"
 
 #include <QWebEngineCertificateError>
 #include <QWebEngineSettings>
@@ -54,6 +43,7 @@
 #include <QStandardPaths>
 #include <QDesktopWidget>
 #include <QFileDialog>
+#include <QDialogButtonBox>
 
 #include <QFile>
 #include <QAuthenticator>
@@ -68,7 +58,6 @@
 //#include <QWebSecurityOrigin>
 #include "utils.h"
 
-
 WebEnginePage::WebEnginePage(WebEnginePart *part, QWidget *parent)
         : QWebEnginePage(parent),
          m_kioErrorCode(0),
@@ -93,6 +82,16 @@ WebEnginePage::WebEnginePage(WebEnginePart *part, QWidget *parent)
     connect(this, &QWebEnginePage::authenticationRequired,
             this, &WebEnginePage::slotAuthenticationRequired);
     connect(this, &QWebEnginePage::fullScreenRequested, this, &WebEnginePage::changeFullScreenMode);
+
+    //If this part is displaying the developer tools for another part, inform the other page it's not displaying the developer tools anymore.
+    //I'm not sure this is needed, but I think it's better to do it, just to be on the safe side
+    auto unsetInspectedPageIfNeeded = [this](bool ok) {
+        if (ok && inspectedPage() && url().scheme() != QLatin1String("devtools")) {
+            setInspectedPage(nullptr);
+        }
+    };
+    connect(this, &QWebEnginePage::loadFinished, this, unsetInspectedPageIfNeeded);
+
     if(!this->profile()->httpUserAgent().contains(QLatin1String("Konqueror")))
     {
         this->profile()->setHttpUserAgent(this->profile()->httpUserAgent() + " Konqueror (WebEnginePart)");
@@ -211,8 +210,8 @@ static bool domainSchemeMatch(const QUrl& u1, const QUrl& u2)
 
 bool WebEnginePage::acceptNavigationRequest(const QUrl& url, NavigationType type, bool isMainFrame)
 {
-    if (m_urlLoadedByPart != url) {
-        m_urlLoadedByPart = QUrl();
+    if (m_urlRequestedByApp != url) {
+        m_urlRequestedByApp = QUrl();
         
         //Don't open local files using WebEnginePart except if configured to do so by the user. For example
         //for example, this ensures that the "Home" link in the introduction page is opened in Dolphin part 
@@ -349,17 +348,47 @@ static int errorCodeFromReply(QNetworkReply* reply)
 }
 #endif
 
-bool WebEnginePage::certificateError(const QWebEngineCertificateError& ce)
+bool WebEnginePage::certificateError(const QWebEngineCertificateError& _ce)
 {
-    if (ce.isOverridable()) {
-        QString translatedDesc = i18n(ce.errorDescription().toUtf8());
-        QString text = i18n("<p>The server failed the authenticity check (%1). The error is:</p><p><tt>%2</tt></p>Do you want to ignore this error?",
-                            ce.url().host(), translatedDesc);
-        KMessageBox::ButtonCode ans = KMessageBox::questionYesNo(view(), text, i18n("Authentication error"));
-        return ans == KMessageBox::Yes;
-    } else {
+    QWebEngineCertificateError ce(_ce);
+    if (!ce.isOverridable()) {
         return false;
     }
+    int error = static_cast<int>(ce.error());
+    QString url = ce.url().url();
+    KConfigGroup grp(KSharedConfig::openConfig(), "CertificateExceptions");
+    QList<int> exceptionsForUrl = grp.readEntry(url, QList<int>{});
+    if (exceptionsForUrl.contains(error)) {
+        return true;
+    } else {
+        ce.defer();
+        WebEnginePartCertificateErrorDlg *dlg = new WebEnginePartCertificateErrorDlg(ce, view());
+        connect(dlg, &WebEnginePartCertificateErrorDlg::finished, this, [this, dlg](int _){handleCertificateError(dlg);});
+        dlg->open();
+        return true;
+    }
+}
+
+void WebEnginePage::handleCertificateError(WebEnginePartCertificateErrorDlg *dlg) {
+    if (!dlg) {
+        return;
+    }
+    QWebEngineCertificateError error = dlg->certificateError();
+    WebEnginePartCertificateErrorDlg::UserChoice choice = dlg->userChoice();
+    dlg->deleteLater();
+    if (choice == WebEnginePartCertificateErrorDlg::UserChoice::DontIgnoreError) {
+        error.rejectCertificate();
+    } else {
+        error.ignoreCertificateError();
+        if (choice == WebEnginePartCertificateErrorDlg::UserChoice::IgnoreErrorForever) {
+            KConfigGroup grp(KSharedConfig::openConfig(), "CertificateExceptions");
+            QString url = error.url().url();
+            QList<int> exceptionsForUrl = grp.readEntry(url, QList<int>{});
+            exceptionsForUrl.append(error.error());
+            grp.writeEntry(url, exceptionsForUrl);
+            grp.sync();
+        }
+    }
 }
 
 WebEnginePart* WebEnginePage::part() const
