@@ -1,26 +1,14 @@
 /*
- * This file is part of the KDE project.
- *
- * Copyright (C) 2007 Trolltech ASA
- * Copyright (C) 2008 - 2010 Urs Wolfer <uwolfer @ kde.org>
- * Copyright (C) 2008 Laurent Montel <montel@kde.org>
- * Copyright (C) 2009 Dawit Alemayehu <adawit@kde.org>
- * Copyright (C) 2013 Allan Sandfeld Jensen <sandfeld@kde.org>
- *
- * This library is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as published by the
- * Free Software Foundation; either version 2.1 of the License, or (at your
- * option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
- * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    This file is part of the KDE project.
+
+    SPDX-FileCopyrightText: 2007 Trolltech ASA
+    SPDX-FileCopyrightText: 2008-2010 Urs Wolfer <uwolfer @ kde.org>
+    SPDX-FileCopyrightText: 2008 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2009 Dawit Alemayehu <adawit@kde.org>
+    SPDX-FileCopyrightText: 2013 Allan Sandfeld Jensen <sandfeld@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "webenginepart.h"
 #include "webenginepartkiohandler.h"
@@ -419,6 +407,10 @@ bool WebEnginePart::openUrl(const QUrl &_u)
 {
     QUrl u (_u);
 
+    if (property("urlRequestedByApp").toString() == u.url()) {
+        page()->markUrlAsRequestedByApp(u);
+    }
+
     // Ignore empty requests...
     if (u.isEmpty())
         return false;
@@ -457,7 +449,6 @@ bool WebEnginePart::openUrl(const QUrl &_u)
     // Set URL in KParts before emitting started; konq plugins rely on that.
     setUrl(u);
     m_doLoadFinishedActions = true;
-    page()->setLoadUrlCalledByPart(u);
     m_webView->loadUrl(u, args, bargs);
     return true;
 }
@@ -966,7 +957,6 @@ void WebEnginePart::slotSaveFormDataRequested (const QString& key, const QUrl& u
             qCWarning(WEBENGINEPART_LOG) << "No m_wallet instance found! This should never happen!";
             return;
         }
-        m_passwordBar->setForms(m_wallet->pendingSaveData(key));
         connect(m_passwordBar, &PasswordBar::saveFormDataAccepted,
                 m_wallet, &WebEngineWallet::acceptSaveFormDataRequest);
         connect(m_passwordBar, &PasswordBar::saveFormDataRejected,
@@ -976,6 +966,7 @@ void WebEnginePart::slotSaveFormDataRequested (const QString& key, const QUrl& u
 
     Q_ASSERT(m_passwordBar);
 
+    m_passwordBar->setForms(m_wallet->pendingSaveData(key));
     m_passwordBar->setUrl(url);
     m_passwordBar->setRequestKey(key);
     m_passwordBar->setText(i18n("<html>Do you want %1 to remember the login "
@@ -1050,8 +1041,8 @@ void WebEnginePart::slotWalletSavedForms(const QUrl& url, bool success)
 void WebEnginePart::createWalletActions()
 {
     QAction *a = new QAction(i18nc("Fill the Forms with Data from KWallet", "&Fill forms now"), this);
-    a->setShortcut(QKeySequence("Ctrl+Shift+V"));
     actionCollection()->addAction("walletFillFormsNow", a);
+    actionCollection()->setDefaultShortcut(a, QKeySequence("Ctrl+Shift+V"));
     connect(a, &QAction::triggered, this, [this]{if(page() && m_wallet){m_wallet->detectAndFillPageForms(page());}});
 
     a = new QAction(i18n("&Memorize Passwords in This Page Now"), this);
@@ -1132,3 +1123,13 @@ void WebEnginePart::updateWalletData(std::initializer_list<bool> data)
     updateWalletActions();
     updateWalletStatusBarIcon();
 }
+
+void WebEnginePart::setInspectedPart(KParts::ReadOnlyPart* part)
+{
+    WebEnginePart *wpart = qobject_cast<WebEnginePart*>(part);
+    if (!wpart) {
+        return;
+    }
+    page()->setInspectedPage(wpart->page());
+    setUrl(page()->url());
+}
