@@ -1,25 +1,11 @@
 /*
- * This file is part of the KDE project.
- *
- * Copyright (C) 2009 Dawit Alemayehu <adawit@kde.org>
- * Copyright (C) 2018 Stefano Crocco <stefano.crocco@alice.it>
- * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- */
+    This file is part of the KDE project.
+
+    SPDX-FileCopyrightText: 2009 Dawit Alemayehu <adawit@kde.org>
+    SPDX-FileCopyrightText: 2018 Stefano Crocco <stefano.crocco@alice.it>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "webenginewallet.h"
 #include "webenginepage.h"
@@ -96,6 +82,10 @@ bool WebEngineWallet::WebForm::hasAutoFillableFields() const
     return std::any_of(fields.constBegin(), fields.constEnd(), [](const WebField &f){return !f.disabled && !f.readOnly && f.autocompleteAllowed;});
 }
 
+bool WebEngineWallet::WebForm::hasFieldsWithWrittenValues() const
+{
+    return std::any_of(fields.constBegin(), fields.constEnd(), [](const WebField &f){return !f.readOnly && !f.value.isEmpty();});
+}
 
 WebEngineWallet::WebForm::WebFieldType WebEngineWallet::WebForm::fieldTypeFromTypeName(const QString& name)
 {
@@ -247,7 +237,9 @@ void WebEngineWallet::saveFormData(WebEnginePage *page, const WebFormList &allFo
         d->confirmSaveRequestOverwrites.insert(url);
         saveFormDataToCache(key);
     } else {
-        emit saveFormDataRequested(key, url);
+        if (std::any_of(formsToSave.constBegin(), formsToSave.constEnd(), [](const WebForm &f){return f.hasFieldsWithWrittenValues();})) {
+            emit saveFormDataRequested(key, url);
+        }
     }
 }
 
