@@ -1,25 +1,11 @@
 /*
- * This file is part of the KDE project.
- *
- * Copyright (C) 2009 Dawit Alemayehu <adawit@kde.org>
- * Copyright (C) 2018 Stefano Crocco <stefano.crocco@alice.it>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- */
+    This file is part of the KDE project.
+
+    SPDX-FileCopyrightText: 2009 Dawit Alemayehu <adawit@kde.org>
+    SPDX-FileCopyrightText: 2018 Stefano Crocco <stefano.crocco@alice.it>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 #ifndef WEBENGINEWALLET_H
 #define WEBENGINEWALLET_H
 
@@ -138,6 +124,13 @@ public:
          */
         bool hasAutoFillableFields() const;
 
+        /**
+         * @brief Whether any of the writable fields in the form have non-empty values
+         *
+         * @return @b true if at least one of the #fields is not read-only and has a non-empty value
+         */
+        bool hasFieldsWithWrittenValues() const;
+
         /**
          * @brief Creates a WebEngineSettings::WebFormInfo from this object
          *
